yt.visualization.volume_rendering.transfer_functions.ProjectionTransferFunction.link_channels — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.transfer_functions.ProjectionTransferFunction.link_channels

`ProjectionTransferFunction.` `link_channels`(table_id, channels=0)

  Link an image channel to a field table.

  Once a field table has been added, it can be linked against a channel (any one of the six – red, green, blue, red absorption, green absorption, blue absorption) and then the value calculated for that field table will be added to the integration for that channel. Not all tables must be linked against channels.

  Parameters: | table_id : int The 0-indexed table to link. channels : int or list of ints The channel or channels to link with this table’s calculated value.

  Examples

  This example shows how to link a new transfer function against field 0, and then link that table against all three RGB channels. Typically an absorption (or ‘alpha’) channel is also linked.

      >>> mv = MultiVariateTransferFunction()
      >>> tf = TransferFunction( (-10.0, -5.0) )
      >>> tf.add_gaussian( -7.0, 0.01, 1.0)
      >>> mv.add_field_table(tf, 0)
      >>> mv.link_channels(0, [0,1,2])